<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: 6049a41 (2023-12-25 02:55:43)
//

defined('_QUICK_LP') or die("Access denied");

class QLPUtil {
	/*
	* @param  string $ip    IP to check in IPV4 format eg. 127.0.0.1
	* @param  string $range IP/CIDR netmask eg. 127.0.0.0/24, also 127.0.0.1 is accepted and /32 assumed
	*/
	public static function ip_in_range( $ip, $range ) {
		if ( strpos( $range, '/' ) == false ) $range .= '/32';
		list( $range, $netmask ) = explode( '/', $range, 2 );
		$range_decimal = ip2long( $range );
		$ip_decimal = ip2long( $ip );
		$wildcard_decimal = pow( 2, ( 32 - $netmask ) ) - 1;
		$netmask_decimal = ~ $wildcard_decimal;
		return ( ( $ip_decimal & $netmask_decimal ) == ( $range_decimal & $netmask_decimal ) );
	}
	public static function isIP($ip){
		return filter_var($ip, FILTER_VALIDATE_IP);
	}
	public static function log2file($data="", $file="log.txt") {
		self::dump2file($data, $file);
	}
	public static function dump2file($data="", $file="log.txt") {
		$text = '=> '.date('Y-m-d H:i:s').' ';
		$text = $text . '(' . gettype($data) . ')' . ' ';
		$text = $text . var_export($data, true);
		$text = $text . "\n";
		file_put_contents(QLP_TMP.$file, $text, FILE_APPEND);
	}
	public static function pre() {
		$all_args=func_get_args();
		$i=0;
		foreach($all_args as $arg){
			$i++;
			echo "<pre>Param #".$i."=>";
			var_dump($arg);
			echo "</pre>";
		}
	}
	public static function halt($msg="") {
		die($msg); 
	}
	//-------- Intrusion detection --------
	public static function checkIntrusion($queryString=false) {
		if(QLPSession::getInstance()->canModifyFE()) return;
		// проверяем входящую строку или то что пришло в запросе после знака вопроса
		if (!$queryString) { // запрещаем ссылки вида http://сайт/?
			if(preg_match("/^\/\?(.*)/",$_SERVER['REQUEST_URI'])){ self::fatalError("Page absent","404"); }
			$queryString = strtolower($_SERVER['QUERY_STRING']); // забираем весь QUERY_STRING для дальнейшей проверки
		}
		// проверяем встречаемость 5 подряд символов
		if (preg_match("/([OdWo5NIbpuU4V2iJT0n]{5}) /", rawurldecode($loc=$queryString), $matches)) { self::fatalError("", "403"); }
		if ((stristr($queryString,'%20union%20'))
				||(stristr($queryString,'/*'))
				||(stristr($queryString,'*/union/*'))
				||(stristr($queryString,'c2nyaxb0'))
				||(stristr($queryString,'+union+'))
				||(stristr($queryString,'http://'))
				||((stristr($queryString,'cmd=')) && (!stristr($queryString,'&cmd')))
				||((stristr($queryString,'exec')) && (!stristr($queryString,'execu')))
				||(stristr($queryString,'concat'))) {
			header("Location: index.php");
		}
	}
	public function fatalError($msg="", $code="404"){
		// @TODO make other page
		require_once QLP_SITE."404.html";
		self::halt();
	}
	public static function checkServerSettings($critic=false) {
		$settings_ok = true; $msg="";
		if (intval(ini_get('register_globals')) == 1) { $settings_ok = false; $msg="CMS required register_globals to be disabled.<br />"; }
		if (version_compare(phpversion(), '5.3.0', '<') == true) { $settings_ok = false; $msg="CMS required PHP version >=5.3<br />"; }
		if (!$settings_ok && $critic) QLPUtil::halt("Invalid server settings.<br />".$msg);
		return $settings_ok;
	}
	public static function redirect($url="index.php", $message="") {
		self::setSystemMessage($message);
		$_sent=headers_sent();
		@ob_end_clean(); // clear output buffer
		if ($_sent) {
			echo "<script>document.location.href='$url';</script>\n";
		}	else {
			header("Location: ".$url);
		}		
		self::halt();
	}
	public static function setSystemMessage($msg=""){
		if(!isset($_SESSION['QLP_MESSAGE'])) $_SESSION['QLP_MESSAGE']="";
		if($_SESSION['QLP_MESSAGE']) $_SESSION['QLP_MESSAGE'].="<br />".$msg;
		else $_SESSION['QLP_MESSAGE']=$msg;
	}
	public static function getSystemMessage($reset=false){
		$result=QLPSession::getVar("QLP_MESSAGE");
		if($reset) QLPSession::unsetVar("QLP_MESSAGE");
		return $result;
	}
	public static function checkFlood($delay=0, $check_if_set=0){
		if(!$delay) $delay=QLPConfig::$floodDelay;
		if (isset($_SESSION['flood_point'])) {
			if (($_SESSION['flood_point']+$delay) > microtime(1)) {
				return true;
			} else {
				self::setFloodPoint();
				return false;
			}
		} else {
			self::setFloodPoint();
			return $check_if_set;
		}
	}
	public static function setFloodPoint(){
		$_SESSION['flood_point']=microtime(1);
	}
	public static function checkEmail($email){
		if(!trim($email)) return false;
		// проверяем правильность email
		if(!preg_match("/^[_\.a-z0-9-]{1,20}@(([a-z0-9-]+\.)+(com|net|org|mil|edu|gov|arpa|info|biz|inc|name|[a-z]{2})|[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3})$/is",$email))  return false;
		return true;
	}
	public static function checkPhone($phone){
		if(!trim($phone)) return false;
		// проверяем правильность телефона
		if(!preg_match("/^((8|\+7)[\- ]?)?(\(?\d{3}\)?[\- ]?)?[\d\- ]{7,10}$/is",$phone))  return false;
		return true;
	}
	public static function dsPath($path, $prefix=false) {
		$path=str_replace("/", DS, $path);
		if ($prefix) return str_replace(DS.DS,DS,$prefix.$path);
		return $path;
	}
	
}